##******************************************************************************
## CoExpress: PCA routine
## ---------------------------------
## 1) Extract the datafile path from %COEXPRESS_DATAPATH%-variable
## 2) Extract the I/O datafile names from %COEXPRESS_DATANAMEIN% and %COEXPRESS_DATANAMEOUT%
## 3) Calculate PCA
## 4) Save 3 PCs into folder scripts/temp.pca.txt
##
## (c) GPL, P.Nazarov 2009-12-13
##******************************************************************************
rm(list=ls()) # clear variables if any exists :)

## get names from system variables
PATH=as.character(Sys.getenv("COEXPRESS_DATAPATH"))
INFILE=as.character(Sys.getenv("COEXPRESS_DATANAMEIN"))
OUTFILE=as.character(Sys.getenv("COEXPRESS_DATANAMEOUT"))

##--------------------------------------------
## load data from PATH/INFILE
Data = read.table(paste(PATH,INFILE,sep="/"),
                  header=T,as.is=T,
                  sep="\t", quote = "\"", comment.char = "#", dec = ".")

##--------------------------------------------
## Calculate PCA

## Remove NA
if (sum(is.na(Data))>0){
  m=apply(Data[,-(1:2)],2,mean,na.rm=T)
  for (i in 3:ncol(Data))
    Data[is.na(Data[,i]),i]=m[i-2]
}

## Calculate PCA
rownames(Data)=Data$ID
pc=prcomp(Data[,-(1:2)], scale=T)

##--------------------------------------------
## save PC data to PATH/OUTFILE
PC.Table=data.frame(matrix(nc=4,nr=nrow(Data)))
PC.Table[,1]=Data$ID
PC.Table[,-1]=pc$x[,1:3]
names(PC.Table)=c("ID","PC1","PC2","PC3")

write.table(PC.Table,paste(PATH,OUTFILE,sep="/"),
                 quote=T, sep="\t", eol="\n", row.names = F)

## Test
#plot(pc$x[,2],pc$x[,1],pch=19)
#for (i in 1:nrow(Data))
#  text(pc$x[i,2]+1,pc$x[i,1],Data$ID[i],cex=0.6)