##******************************************************************************
## CoExpress: an example of data normalization
## ---------------------------------
## 1) Extract the datafile path from %COEXPRESS_DATAPATH%-variable
## 2) Extract the I/O datafile names from %COEXPRESS_DATANAMEIN% and %COEXPRESS_DATANAMEOUT%
## 3) Process the data
## 4) Save to the same folder with the name specified in CoExpress
##
## (c) GPL, P.Nazarov 2009-12-12
##******************************************************************************
rm(list=ls()) # clear variables if any exists :)

## get names from system variables
PATH=as.character(Sys.getenv("COEXPRESS_DATAPATH"))
INFILE=as.character(Sys.getenv("COEXPRESS_DATANAMEIN"))
OUTFILE=as.character(Sys.getenv("COEXPRESS_DATANAMEOUT"))

##--------------------------------------------
## load data from PATH/INFILE
Data = read.table(paste(PATH,INFILE,sep="/"),
                  header=T,as.is=T,
                  sep="\t", quote = "\"", comment.char = "#", dec = ".")

##--------------------------------------------
## Perform linear normalization between arrays
## (put you processiong in this section!)

m=apply(Data[,c(-1,-2)],2,mean,na.rm=T)
s=apply(Data[,c(-1,-2)],2,sd,na.rm=T)

m.total=mean(m);
s.total=sqrt(mean(s^2))

for (i in 1:(ncol(Data)-2)){
  Data[,i+2]=s.total*(Data[,i+2]-m[i])/s[i]+m.total
  if (i%%100 == 0) {
    print(i)
    flush.console()
  }
}

##--------------------------------------------
## save data to PATH/OUTFILE
write.table(Data,paste(PATH,OUTFILE,sep="/"),
                 quote=T, sep="\t", eol="\n", row.names = F)

